# Template {{window_id}}

Initializing...

x
None selected
i
Your Obsidian Vault folder. Select the first (sub)folder that by itself contains all the notes in your vault.
None selected
i
The note that is to become the homepage of your new site. In default mode, ObsidianHtml will start compiling your website starting with this node, and following any links to any other note. This note has to be in the vault selected above.
Entrypoint
Failed to load setting
i
The note that is to become the homepage of your new site. In default mode, ObsidianHtml will start compiling your website starting with this note, and following any links to any other note. This note has to be in the vault selected above.

## Summary

None selected
i
The note that is to become the homepage of your new site. In default mode, ObsidianHtml will start compiling your website starting with this node, and following any links to any other note. This note has to be in the vault selected above.
Entrypoint
Failed to load setting
i
The note that is to become the homepage of your new site. In default mode, ObsidianHtml will start compiling your website starting with this note, and following any links to any other note. This note has to be in the vault selected above.